@@ -43,8 +43,10 @@ class FoafDocument(Document):
     _format: str
     _rdfs_see_also: str
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         self._type = FOAF.Document
 
     @property
@@ -86,6 +88,7 @@ class FoafDocument(Document):
         self._g = Graph()
         self._g.bind("dct", DCTERMS)
         self._g.bind("foaf", FOAF)
+        self._g.bind("rdfs", RDFS)
 
         if not getattr(self, "identifier", None):
             self.identifier = Skolemizer.add_skolemization()
