@@ -40,6 +40,56 @@ XKOS = Namespace("http://rdf-vocabulary.ddialliance.org/xkos#")
 ADMS = Namespace("http://www.w3.org/ns/adms#")
 
 
+class Standard:
+    """A class representing a dct:Standard."""
+
+    __slots__ = ("_g", "_identifier")
+
+    _g: Graph
+    _identifier: URI
+
+    @property
+    def identifier(self) -> str:
+        """Get for identifier."""
+        return self._identifier
+
+    @identifier.setter
+    def identifier(self, identifier: str) -> None:
+        self._identifier = URI(identifier)
+
+    def to_rdf(
+        self, format: str = "turtle", encoding: Optional[str] = "utf-8"
+    ) -> bytes:
+        """Maps the standard to rdf.
+
+        Args:
+            format: a valid format. Default: turtle
+            encoding: the encoding to serialize into
+
+        Returns:
+            a rdf serialization as a string according to format encoded as bytes.
+        """
+        return self._to_graph().serialize(format=format, encoding=encoding)
+
+    def _to_graph(self) -> Graph:
+        """Returns the standard as graph.
+
+        Returns:
+            the graph graph
+        """
+        self._g = Graph()
+        self._g.bind("dct", DCTERMS)
+
+        if not getattr(self, "identifier", None):
+            self.identifier = Skolemizer.add_skolemization()
+
+        _self = URIRef(self.identifier)
+
+        self._g.add((_self, RDF.type, DCTERMS.Standard))
+
+        return self._g
+
+
 class InformationModel(Resource):
     """A class representing a modelldatno:InformationModel."""
 
@@ -92,8 +142,11 @@ class InformationModel(Resource):
     _has_format: List[Union[FoafDocument, str]]
     _temporal: List[PeriodOfTime]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits InformationModel object with default values."""
+        if identifier:
+            self.identifier = identifier
+
         super().__init__()
         self._type = MODELLDCATNO.InformationModel
         self._subject = []
@@ -1204,8 +1257,10 @@ class Role(ModelProperty):
     _has_object_type: Union[ObjectType, URI]
     _g: Graph
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     @property
@@ -1285,8 +1340,10 @@ class ObjectType(ModelElement):
     _g: Graph
     _belongs_to_module: List[str]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -1355,8 +1412,10 @@ class SimpleType(ModelElement):
     _pattern: str
     _belongs_to_module: List[str]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     @property
@@ -1543,8 +1602,10 @@ class Composition(ModelProperty):
         """Set for contains."""
         self._contains = contains
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -1625,8 +1686,10 @@ class Collection(ModelProperty):
         """Set for has_member."""
         self._has_member = has_member
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -1709,8 +1772,10 @@ class Association(ModelProperty):
         """Set for refers_to."""
         self._refers_to = refers_to
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -1793,8 +1858,10 @@ class Choice(ModelProperty):
         """Set for has_some."""
         self._has_some = has_some
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits Choice object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
         self._has_some = []
 
@@ -1875,8 +1942,10 @@ class Attribute(ModelProperty):
     _has_data_type: Union[DataType, URI]
     _has_value_from: Union[CodeList, URI]
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     @property
@@ -2070,8 +2139,10 @@ class Specialization(ModelProperty):
         """Set for has_general_concept."""
         self._has_general_concept = has_general_concept
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -2154,8 +2225,10 @@ class Realization(ModelProperty):
         """Set for has_supplier."""
         self._has_supplier = has_supplier
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
@@ -2240,8 +2313,10 @@ class Abstraction(ModelProperty):
         """Set for is_abstraction_of."""
         self._is_abstraction_of = is_abstraction_of
 
-    def __init__(self) -> None:
+    def __init__(self, identifier: Optional[str] = None) -> None:
         """Inits an object with default values."""
+        if identifier:
+            self.identifier = identifier
         super().__init__()
 
     def to_rdf(
